@@ -1,6 +1,6 @@
 package DBIx::Custom;
 
-our $VERSION = '0.1677';
+our $VERSION = '0.1678';
 
 use 5.008001;
 use strict;
@@ -78,7 +78,8 @@ sub AUTOLOAD {
         $self->dbh->$dbh_method(@_);
     }
     else {
-        croak qq/Can't locate object method "$mname" via "$package"/
+        croak qq{Can't locate object method "$mname" via "$package"}
+            . qq{ (DBIx::Custom::AUTOLOAD)}
     }
 }
 
@@ -110,10 +111,11 @@ sub apply_filter {
         
         # Filter infomation
         my $finfo = $cinfos[$i + 1] || {};
-        croak "$usage (table: $table)" unless  ref $finfo eq 'HASH';
+        croak "$usage (table: $table) (DBIx::Custom::apply_filter)"
+          unless  ref $finfo eq 'HASH';
         foreach my $ftype (keys %$finfo) {
-            croak "$usage (table: $table 2)" unless $ftype eq 'in' || $ftype eq 'out'
-                             || $ftype eq 'end'; 
+            croak "$usage (table: $table) (DBIx::Custom::apply_filter)"
+              unless $ftype eq 'in' || $ftype eq 'out' || $ftype eq 'end'; 
         }
         
         # Set filters
@@ -133,6 +135,7 @@ sub apply_filter {
             
             # Check filter name
             croak qq{Filter "$filter" is not registered}
+                . qq{ (DBIx::Custom::apply_filter)}
               if  $state eq 'name'
                && ! exists $self->filters->{$filter};
             
@@ -223,7 +226,11 @@ sub create_query {
     # Prepare statement handle
     my $sth;
     eval { $sth = $self->dbh->prepare($query->{sql})};
-    $self->_croak($@, qq{. Following SQL is executed. "$query->{sql}"}) if $@;
+    
+    if ($@) {
+        $self->_croak($@, qq{. Following SQL is executed.\n}
+                        . qq{$query->{sql}\n(DBIx::Custom::create_query)});
+    }
     
     # Set statement handle
     $query->sth($sth);
@@ -249,6 +256,7 @@ sub dbh {
         # From Connction manager
         if (my $connector = $self->connector) {
             croak "connector must have dbh() method"
+                . " (DBIx::Custom::dbh)"
               unless ref $connector && $connector->can('dbh');
               
             return $self->{dbh} = $connector->dbh;
@@ -266,13 +274,15 @@ sub delete {
 
     # Check arguments
     foreach my $name (keys %args) {
-        croak qq{Argument "$name" is wrong name}
+        croak qq{"$name" is wrong option}
+            . qq{ (DBIx::Custom::delete)}
           unless $DELETE_ARGS{$name};
     }
     
     # Arguments
     my $table = $args{table} || '';
-    croak qq{"table" option must be specified} unless $table;
+    croak qq{"table" option must be specified. (DBIx::Custom::delete)}
+      unless $table;
     my $where            = delete $args{where} || {};
     my $append           = delete $args{append};
     my $allow_delete_all = delete $args{allow_delete_all};
@@ -283,7 +293,7 @@ sub delete {
     
     # Where clause
     my $where_clause = $where->to_string;
-    croak qq{"where" must be specified}
+    croak qq{"where" must be specified (DBIx::Custom::delete)}
       if $where_clause eq '' && !$allow_delete_all;
 
     # Delete statement
@@ -320,13 +330,12 @@ sub delete_at {
     
     # Check arguments
     foreach my $name (keys %args) {
-        croak qq{Argument "$name" is wrong name}
+        croak qq{"$name" is wrong option (DBIx::Custom::delete_at)}
           unless $DELETE_AT_ARGS{$name};
     }
     
     # Create where parameter
     my $where_param = $self->_create_where_param($where, $primary_keys);
-
     
     return $self->delete(where => $where_param, %args);
 }
@@ -350,12 +359,14 @@ sub create_model {
     $model->table($model_table) unless $model->table;
     
     # Apply filter
-    croak "$model_class filter must be array reference"
-      unless ref $model->filter eq 'ARRAY';
-    $self->apply_filter($model->table, @{$model->filter});
+    my $filter = ref $model->filter eq 'HASH'
+               ? [%{$model->filter}]
+               : $model->filter;
+    $self->apply_filter($model->table, @$filter);
     
     # Associate table with model
     croak "Table name is duplicated"
+        . " (DBIx::Custom::create_model)"
       if exists $self->{_model_from}->{$model->table};
     $self->{_model_from}->{$model->table} = $model->name;
 
@@ -404,7 +415,7 @@ sub execute {
     
     # Check argument names
     foreach my $name (keys %args) {
-        croak qq{Argument "$name" is wrong name}
+        croak qq{"$name" is wrong option (DBIx::Custom::execute)}
           unless $EXECUTE_ARGS{$name};
     }
     
@@ -464,6 +475,7 @@ sub execute {
         }
         elsif (ref $name ne 'CODE') {
           croak qq{Filter "$name" is not registered"}
+              . qq{ (DBIx::Custom::execute}
             unless exists $self->filters->{$name};
           $filter->{$column} = $self->filters->{$name};
         }
@@ -487,7 +499,11 @@ sub execute {
         }
         $affected = $sth->execute;
     };
-    $self->_croak($@, qq{. Following SQL is executed. "$query->{sql}"}) if $@;
+    
+    if ($@) {
+        $self->_croak($@, qq{. Following SQL is executed.\n}
+                        . qq{$query->{sql}\n});
+    }
     
     # Output SQL for debug
     warn $query->sql . "\n" if DEBUG;
@@ -532,14 +548,15 @@ sub insert {
     
     # Arguments
     my $table  = delete $args{table};
-    croak qq{"table" option must be specified} unless $table;
+    croak qq{"table" option must be specified (DBIx::Custom::insert)}
+      unless $table;
     my $param  = delete $args{param} || {};
     my $append = delete $args{append} || '';
     my $query_return  = delete $args{query};
 
     # Check arguments
     foreach my $name (keys %args) {
-        croak qq{Argument "$name" is wrong name}
+        croak qq{"$name" is wrong option (DBIx::Custom::insert)}
           unless $INSERT_ARGS{$name};
     }
 
@@ -551,6 +568,7 @@ sub insert {
     my $safety = $self->safety_character;
     foreach my $column (keys %$param) {
         croak qq{"$column" is not safety column name}
+            . qq{ (DBIx::Custom::insert)}
           unless $column =~ /^[$safety\.]+$/;
           $column = "$q$column$q";
           $column =~ s/\./$q.$q/;
@@ -589,7 +607,7 @@ sub insert_at {
     
     # Check arguments
     foreach my $name (keys %args) {
-        croak qq{Argument "$name" is wrong name}
+        croak qq{"$name" is wrong option (DBIx::Custom::insert_at)}
           unless $INSERT_AT_ARGS{$name};
     }
     
@@ -610,6 +628,7 @@ sub insert_param_tag {
     my @placeholders;
     foreach my $column (keys %$param) {
         croak qq{"$column" is not safety column name}
+            . qq{ (DBIx::Custom::insert_param_tag) }
           unless $column =~ /^[$safety\.]+$/;
         $column = "$q$column$q";
         $column =~ s/\./$q.$q/;
@@ -632,15 +651,19 @@ sub include_model {
 
         # Load name space module
         croak qq{"$name_space" is invalid class name}
+            . qq{ (DBIx::Custom::include_model)}
           if $name_space =~ /[^\w:]/;
         eval "use $name_space";
-        croak qq{Name space module "$name_space.pm" is needed. $@} if $@;
+        croak qq{Name space module "$name_space.pm" is needed. $@}
+            . qq{ (DBIx::Custom::include_model)}
+          if $@;
         
         # Search model modules
         my $path = $INC{"$name_space.pm"};
         $path =~ s/\.pm$//;
         opendir my $dh, $path
-          or croak qq{Can't open directory "$path": $!};
+          or croak qq{Can't open directory "$path": $!}
+                 . qq{ (DBIx::Custom::include_model)};
         $model_infos = [];
         while (my $module = readdir $dh) {
             push @$model_infos, $module
@@ -667,10 +690,11 @@ sub include_model {
         else { $model_class = $model_name = $model_table = $model_info }
         my $mclass = "${name_space}::$model_class";
         croak qq{"$mclass" is invalid class name}
+            . qq{ (DBIx::Custom::inculde_model)}
           if $mclass =~ /[^\w:]/;
         unless ($mclass->can('isa')) {
             eval "use $mclass";
-            croak $@ if $@;
+            croak "$@ (DBIx::Custom::include_model)" if $@;
         }
         
         # Create model
@@ -725,7 +749,7 @@ sub model {
     }
     
     # Check model existance
-    croak qq{Model "$name" is not included}
+    croak qq{Model "$name" is not included (DBIx::Custom::model)}
       unless $self->models->{$name};
     
     # Get model
@@ -750,7 +774,7 @@ sub new {
     # Check attributes
     my @attrs = keys %$self;
     foreach my $attr (@attrs) {
-        croak qq{"$attr" is wrong name}
+        croak qq{"$attr" is wrong name (DBIx::Custom::new)}
           unless $self->can($attr);
     }
     
@@ -802,6 +826,7 @@ sub select {
     my $append    = delete $args{append};
     my $join      = delete $args{join} || [];
     croak qq{"join" must be array reference}
+        . qq{ (DBIx::Custom::select)}
       unless ref $join eq 'ARRAY';
     my $relation = delete $args{relation};
     my $param = delete $args{param} || {};
@@ -809,7 +834,7 @@ sub select {
 
     # Check arguments
     foreach my $name (keys %args) {
-        croak qq{Argument "$name" is wrong name}
+        croak qq{"$name" is wrong option (DBIx::Custom::select)}
           unless $SELECT_ARGS{$name};
     }
     
@@ -846,7 +871,8 @@ sub select {
         push @sql, "$q$main_table$q";
     }
     pop @sql if ($sql[-1] || '') eq ',';
-    croak "Not found table name" unless $tables->[-1];
+    croak "Not found table name (DBIx::Custom::select)"
+      unless $tables->[-1];
 
     # Add tables in parameter
     unshift @$tables, @{$self->_search_tables(join(' ', keys %$param) || '')};
@@ -905,12 +931,13 @@ sub select_at {
     
     # Check arguments
     foreach my $name (keys %args) {
-        croak qq{Argument "$name" is wrong name}
+        croak qq{"$name" is wrong option (DBIx::Custom::select_at)}
           unless $SELECT_AT_ARGS{$name};
     }
     
     # Table
-    croak qq{"table" option must be specified} unless $args{table};
+    croak qq{"table" option must be specified (DBIx::Custom::select_at)}
+      unless $args{table};
     my $table = ref $args{table} ? $args{table}->[-1] : $args{table};
     
     # Create where parameter
@@ -942,7 +969,8 @@ sub update {
 
     # Arguments
     my $table = delete $args{table} || '';
-    croak qq{"table" option must be specified} unless $table;
+    croak qq{"table" option must be specified (DBIx::Custom::update)}
+      unless $table;
     my $param            = delete $args{param} || {};
     my $where            = delete $args{where} || {};
     my $append           = delete $args{append} || '';
@@ -950,7 +978,7 @@ sub update {
     
     # Check argument names
     foreach my $name (keys %args) {
-        croak qq{Argument "$name" is wrong name}
+        croak qq{"$name" is wrong option (DBIx::Custom::update)}
           unless $UPDATE_ARGS{$name};
     }
     
@@ -960,6 +988,7 @@ sub update {
     my $q = $self->reserved_word_quote;
     foreach my $column (keys %$param) {
         croak qq{"$column" is not safety column name}
+            . qq{ (DBIx::Custom::update)}
           unless $column =~ /^[$safety\.]+$/;
           $column = "$q$column$q";
           $column =~ s/\./$q.$q/;
@@ -972,7 +1001,7 @@ sub update {
     # Where
     $where = $self->_where_to_obj($where);
     my $where_clause = $where->to_string;
-    croak qq{"where" must be specified}
+    croak qq{"where" must be specified (DBIx::Custom::update)}
       if "$where_clause" eq '' && !$allow_update_all;
     
     # Update statement
@@ -1016,7 +1045,7 @@ sub update_at {
 
     # Check arguments
     foreach my $name (keys %args) {
-        croak qq{Argument "$name" is wrong name}
+        croak qq{"$name" is wrong option (DBIx::Custom::update_at)}
           unless $UPDATE_AT_ARGS{$name};
     }
     
@@ -1026,23 +1055,6 @@ sub update_at {
     return $self->update(where => $where_param, %args);
 }
 
-sub _create_where_param {
-    my ($self, $where, $primary_keys) = @_;
-    
-    # Create where parameter
-    my $where_param = {};
-    if ($where) {
-        $where = [$where] unless ref $where;
-        croak qq{"where" must be constant value or array reference}
-          unless !ref $where || ref $where eq 'ARRAY';
-        for(my $i = 0; $i < @$primary_keys; $i ++) {
-           $where_param->{$primary_keys->[$i]} = $where->[$i];
-        }
-    }
-    
-    return $where_param;
-}
-
 sub update_param_tag {
     my ($self, $param, $opt) = @_;
     
@@ -1052,6 +1064,7 @@ sub update_param_tag {
     my $q = $self->reserved_word_quote;
     foreach my $column (keys %$param) {
         croak qq{"$column" is not safety column name}
+            . qq{ (DBIx::Custom::update_param_tag) }
           unless $column =~ /^[$safety\.]+$/;
         my $column = "$q$column$q";
         $column =~ s/\./$q.$q/;
@@ -1121,12 +1134,35 @@ sub _create_bind_values {
     return $bind;
 }
 
+sub _create_where_param {
+    my ($self, $where, $primary_keys) = @_;
+    
+    # Create where parameter
+    my $where_param = {};
+    if ($where) {
+        $where = [$where] unless ref $where;
+        croak qq{"where" must be constant value or array reference}
+            . " (" . (caller 1)[3] . ")"
+          unless !ref $where || ref $where eq 'ARRAY';
+        
+        croak qq{"where" must contain values same count as primary key}
+            . " (" . (caller 1)[3] . ")"
+          unless @$primary_keys eq @$where;
+        
+        for(my $i = 0; $i < @$primary_keys; $i ++) {
+           $where_param->{$primary_keys->[$i]} = $where->[$i];
+        }
+    }
+    
+    return $where_param;
+}
+
 sub _connect {
     my $self = shift;
     
     # Attributes
     my $data_source = $self->data_source;
-    croak qq{"data_source" must be specified to connect()"}
+    croak qq{"data_source" must be specified (DBIx::Custom::dbh)"}
       unless $data_source;
     my $user        = $self->user;
     my $password    = $self->password;
@@ -1144,7 +1180,7 @@ sub _connect {
     )};
     
     # Connect error
-    croak $@ if $@;
+    croak "$@ (DBIx::Custom::dbh)" if $@;
     
     return $dbh;
 }
@@ -1200,13 +1236,15 @@ sub _push_join {
         if ($join_clause =~ $join_re) {
             my $table1 = $1;
             my $table2 = $2;
-            croak qq{right side table of "$join_clause" must be uniq}
+            croak qq{right side table of "$join_clause" must be unique}
+                . qq{ (DBIx::Custom::select)}
               if exists $tree->{$table2};
             $tree->{$table2}
               = {position => $i, parent => $table1, join => $join_clause};
         }
         else {
-            croak qq{join "$join_clause" must be two table name};
+            croak qq{join "$join_clause" must be two table name}
+                . qq{ (DBIx::Custom::select)};
         }
     }
     
@@ -1282,8 +1320,9 @@ sub _where_to_obj {
     }
     
     # Check where argument
-    croak qq{"where" must be hash reference or DBIx::Custom::Where object} .
-          qq{or array reference, which contains where clause and paramter}
+    croak qq{"where" must be hash reference or DBIx::Custom::Where object}
+        . qq{or array reference, which contains where clause and paramter}
+        . " (" . (caller(1))[3] . ")"
       unless ref $obj eq 'DBIx::Custom::Where';
     
     return $obj;
@@ -1693,13 +1732,13 @@ and C<PrintError> option is false by default.
         join => [
             'inner join company on book.comparny_id = company.id'
         ],
-        filter => [
+        filter => {
             publish_date => {
                 out => 'tp_to_date',
                 in => 'date_to_tp',
                 end => 'tp_to_displaydate'
             }
-        ]
+        }
     );
 
 Create L<DBIx::Custom::Model> object and initialize model.
@@ -1792,13 +1831,13 @@ filter name registerd by C<register_filter()>.
     # Basic
     $dbi->execute(
         $sql,
-        filter => [
+        filter => {
             title  => sub { uc $_[0] }
             author => sub { uc $_[0] }
-        ]
+        }
     );
     
-    # At once
+    # At once (use array reference)
     $dbi->execute(
         $sql,
         filter => [
@@ -1809,10 +1848,10 @@ filter name registerd by C<register_filter()>.
     # Filter name
     $dbi->execute(
         $sql,
-        filter => [
+        filter => {
             title  => 'upper_case',
             author => 'upper_case'
-        ]
+        }
     );
 
 These filters are added to the C<out> filters, set by C<apply_filter()>.
@@ -1872,13 +1911,13 @@ filter name registerd by C<register_filter()>.
 
     # Basic
     $dbi->delete(
-        filter => [
+        filter => {
             title  => sub { uc $_[0] }
             author => sub { uc $_[0] }
-        ]
+        }
     );
     
-    # At once
+    # At once (use array reference)
     $dbi->delete(
         filter => [
             [qw/title author/]  => sub { uc $_[0] }
@@ -1887,10 +1926,10 @@ filter name registerd by C<register_filter()>.
     
     # Filter name
     $dbi->delete(
-        filter => [
+        filter => {
             title  => 'upper_case',
             author => 'upper_case'
-        ]
+        }
     );
 
 These filters are added to the C<out> filters, set by C<apply_filter()>.
@@ -2010,13 +2049,13 @@ filter name registerd by C<register_filter()>.
 
     # Basic
     $dbi->insert(
-        filter => [
+        filter => {
             title  => sub { uc $_[0] }
             author => sub { uc $_[0] }
-        ]
+        }
     );
     
-    # At once
+    # At once (use array reference)
     $dbi->insert(
         filter => [
             [qw/title author/]  => sub { uc $_[0] }
@@ -2025,10 +2064,10 @@ filter name registerd by C<register_filter()>.
     
     # Filter name
     $dbi->insert(
-        filter => [
+        filter => {
             title  => 'upper_case',
             author => 'upper_case'
-        ]
+        }
     );
 
 These filters are added to the C<out> filters, set by C<apply_filter()>.
@@ -2390,13 +2429,13 @@ filter name registerd by C<register_filter()>.
 
     # Basic
     $dbi->select(
-        filter => [
+        filter => {
             title  => sub { uc $_[0] }
             author => sub { uc $_[0] }
-        ]
+        }
     );
     
-    # At once
+    # At once (use array reference)
     $dbi->select(
         filter => [
             [qw/title author/]  => sub { uc $_[0] }
@@ -2405,10 +2444,10 @@ filter name registerd by C<register_filter()>.
     
     # Filter name
     $dbi->select(
-        filter => [
+        filter => {
             title  => 'upper_case',
             author => 'upper_case'
-        ]
+        }
     );
 
 These filters are added to the C<out> filters, set by C<apply_filter()>.
@@ -2547,13 +2586,13 @@ filter name registerd by C<register_filter()>.
 
     # Basic
     $dbi->update(
-        filter => [
+        filter => {
             title  => sub { uc $_[0] }
             author => sub { uc $_[0] }
-        ]
+        }
     );
     
-    # At once
+    # At once (use array reference)
     $dbi->update(
         filter => [
             [qw/title author/]  => sub { uc $_[0] }
@@ -2562,10 +2601,10 @@ filter name registerd by C<register_filter()>.
     
     # Filter name
     $dbi->update(
-        filter => [
+        filter => {
             title  => 'upper_case',
             author => 'upper_case'
-        ]
+        }
     );
 
 These filters are added to the C<out> filters, set by C<apply_filter()>.
